@@ -38,7 +38,7 @@ else:
 lib = ffi.dlopen(soname)
 
 __xcb_proto_version__ = "1.13"
-__version__ = 'placeholder'
+__version__ = "0.9.0"
 
 X_PROTOCOL = lib.X_PROTOCOL
 X_PROTOCOL_REVISION = lib.X_PROTOCOL_REVISION
@@ -106,10 +106,11 @@ class Unpacker(object):
         self.offset += type_pad(size, self.offset)
 
     def unpack(self, fmt, increment=True):
+        fmt = "=" + fmt
         size = struct.calcsize(fmt)
         if size > self.size - self.offset:
             self._resize(size)
-        ret = struct.unpack_from("=" + fmt, self.buf, self.offset)
+        ret = struct.unpack_from(fmt, self.buf, self.offset)
 
         if increment:
             self.offset += size
@@ -415,7 +416,7 @@ class List(Protobj):
         old = unpacker.offset
 
         if isinstance(typ, str):
-            self.list = list(unpacker.unpack(typ * count))
+            self.list = list(unpacker.unpack("%d%s" % (count, typ)))
         elif count is not None:
             for _ in range(count):
                 item = typ(unpacker)
@@ -461,7 +462,7 @@ class List(Protobj):
 
     def to_atoms(self):
         """ A helper for converting a List of chars to an array of atoms """
-        return struct.unpack("<" + "I" * (len(self) // 4), b''.join(self))
+        return struct.unpack("<" + "%dI" % (len(self) // 4), b''.join(self))
 
     def buf(self):
         return self.raw
@@ -779,7 +780,7 @@ def pack_list(from_, pack_type):
             from_ = [six.int2byte(b) for i in from_ for b in to_bytes(i)]
 
     if isinstance(pack_type, six.string_types):
-        return struct.pack("=" + pack_type * len(from_), *from_)
+        return struct.pack("=%d%s" % (len(from_), pack_type), *from_)
     else:
         buf = six.BytesIO()
         for item in from_:
